@@ -1,6 +1,6 @@
 # --
 # Selenium.pm - run frontend tests
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,13 +13,19 @@ package Kernel::System::UnitTest::Selenium;
 use strict;
 use warnings;
 
-use base qw(Selenium::Remote::Driver);
 use MIME::Base64();
 use File::Temp();
 
 use Kernel::Config;
 use Kernel::System::User;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::UnitTest',
+);
+
 =head1 NAME
 
 Kernel::System::UnitTest::Selenium - run frontend tests
@@ -59,15 +65,11 @@ Then you can use the full API of Selenium::Remote::Driver on this object.
 sub new {
     my ( $Class, %Param ) = @_;
 
-    for my $Needed (qw(UnitTestObject)) {
-        if ( !$Param{$Needed} ) {
-            die "Got no $Needed!";
-        }
-    }
+    $Param{UnitTestObject} ||= $Kernel::OM->Get('Kernel::System::UnitTest');
 
     $Param{UnitTestObject}->True( 1, "Starting up Selenium scenario..." );
 
-    my %SeleniumTestsConfig = %{ $Param{UnitTestObject}->{ConfigObject}->Get('SeleniumTestsConfig') // {} };
+    my %SeleniumTestsConfig = %{ $Kernel::OM->Get('Kernel::Config')->Get('SeleniumTestsConfig') // {} };
 
     if ( !%SeleniumTestsConfig ) {
         my $Self = bless {}, $Class;
@@ -81,6 +83,9 @@ sub new {
         }
     }
 
+    $Kernel::OM->Get('Kernel::System::Main')->RequireBaseClass('Selenium::Remote::Driver')
+        || die "Could not load Selenium::Remote::Driver";
+
     my $Self = $Class->SUPER::new(%SeleniumTestsConfig);
     $Self->{UnitTestObject}      = $Param{UnitTestObject};
     $Self->{SeleniumTestsActive} = 1;
@@ -89,7 +94,7 @@ sub new {
     $Self->set_window_size( 1024, 768 );
 
     # get remote host with some precautions for certain unit test systems
-    my $FQDN = $Self->{UnitTestObject}->{ConfigObject}->Get('FQDN');
+    my $FQDN = $Kernel::OM->Get('Kernel::Config')->Get('FQDN');
 
     # try to resolve fqdn host
     if ( $FQDN ne 'yourhost.example.com' && gethostbyname($FQDN) ) {
@@ -106,7 +111,7 @@ sub new {
         $Self->{BaseURL} = '127.0.0.1';
     }
 
-    $Self->{BaseURL} = $Self->{UnitTestObject}->{ConfigObject}->Get('HttpType') . '://' . $Self->{BaseURL};
+    $Self->{BaseURL} = $Kernel::OM->Get('Kernel::Config')->Get('HttpType') . '://' . $Self->{BaseURL};
 
     return $Self;
 }
@@ -151,7 +156,7 @@ sub _execute_command {    ## no critic
     my $Result = $Self->SUPER::_execute_command( $Res, $Params );
 
     my $TestName = 'Selenium command success: ';
-    $TestName .= $Self->{UnitTestObject}->{MainObject}->Dump(
+    $TestName .= $Kernel::OM->Get('Kernel::System::Main')->Dump(
         {
             %{ $Res    || {} },
             %{ $Params || {} },
@@ -202,9 +207,9 @@ sub Login {
     # check needed stuff
     for (qw(Type User Password)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $_!",
             );
             return;
         }
@@ -215,7 +220,7 @@ sub Login {
     eval {
         $Self->delete_all_cookies();
 
-        my $ScriptAlias = $Self->{UnitTestObject}->{ConfigObject}->Get('ScriptAlias');
+        my $ScriptAlias = $Kernel::OM->Get('Kernel::Config')->Get('ScriptAlias');
 
         if ( $Param{Type} eq 'Agent' ) {
             $ScriptAlias .= 'index.pl';
@@ -244,6 +249,15 @@ sub Login {
         # login
         $Element->submit();
 
+        # Wait until form has loaded, if neccessary
+        ACTIVESLEEP:
+        for my $Second ( 1 .. 20 ) {
+            if ( $Self->execute_script('return typeof($) === "function" && $("a#LogoutButton").length') ) {
+                last ACTIVESLEEP;
+            }
+            sleep 1;
+        }
+
         # login succressful?
         $Element = $Self->find_element( 'a#LogoutButton', 'css' );
 
@@ -285,7 +299,7 @@ sub HandleError {
         UNLINK => 0,
     );
     close $FH;
-    $Self->{UnitTestObject}->{MainObject}->FileWrite(
+    $Kernel::OM->Get('Kernel::System::Main')->FileWrite(
         Location => $Filename,
         Content  => \$Data,
     );
